==============
Why "Rubicon"?
==============

So... why the name Rubicon?
===========================

The Rubicon is a river in Italy. It was of importance in ancient times as the
border of Rome. The Roman Army was prohibited from crossing this border, as that
would be considered a hostile act against the Roman Senate.

In 54 BC, Julius Caesar marched the Roman Army across the Rubicon, signaling
his intention to overthrow the Roman Senate. As he did so, legend says he
uttered the words "Alea Iacta Est" - The die is cast. This action led to Julius
being crowned as Emperor of Rome, and the start of the Roman Empire.

Of course, in order to cross any river, you need to use a bridge.

This project provides a bridge between the open world of the Python
ecosystem, and the Java ecosystem.
